ssbkonf.util — ssbkonf 0.0.6 documentation

# `ssbkonf.util`

## Module Contents

### Functions

`prepare_input`(data[, freq_var, num_var, dim_var, ...]) |
`find_hierarchies`(data[, total]) |
`convert2r`(data) |
`convert2py`(data) |
`convert_formula2r`(formula) |
`convert_hierarchies`(hier) |

ssbkonf.util.prepare_input(data: pandas.DataFrame, freq_var=None, num_var=None, dim_var: list[str] = None, formula: str = None, hierarchies: dict[str, pandas.DataFrame | list[pandas.DataFrame]] = None)

ssbkonf.util.find_hierarchies(data, total='Total')

ssbkonf.util.convert2r(data)

ssbkonf.util.convert2py(data)

ssbkonf.util.convert_formula2r(formula)

ssbkonf.util.convert_hierarchies(hier)